import abc
import builtins
import datetime
import enum
import typing

import jsii
import publication
import typing_extensions

import aws_cdk.aws_ec2._jsii
import aws_cdk.aws_ecs._jsii
import aws_cdk.aws_ecs_patterns._jsii
import aws_cdk.aws_efs._jsii
import aws_cdk.aws_events_targets._jsii
import aws_cdk.aws_iam._jsii
import aws_cdk.aws_lambda._jsii
import aws_cdk.aws_logs._jsii
import aws_cdk.aws_s3._jsii
import aws_cdk.aws_secretsmanager._jsii
import aws_cdk.core._jsii
import aws_cdk.custom_resources._jsii
import cdk_fargate_run_task._jsii
import constructs._jsii

__jsii_assembly__ = jsii.JSIIAssembly.load(
    "cdk-efs-assets", "0.3.93", __name__[0:-6], "cdk-efs-assets@0.3.93.jsii.tgz"
)

__all__ = [
    "__jsii_assembly__",
]

publication.publish()
